@@ -3,634 +3,717 @@
 <context>
     <name>AboutDialog</name>
     <message>
-        <location filename="watchvideo/ui_about.py" line="63"/>
+        <location filename="ui_about.py"/>
         <source>About</source>
-        <translation>O programie</translation>
+        <translation>O programie</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_about.py" line="64"/>
+        <location filename="ui_about.py"/>
         <source>Credits</source>
         <translation>Zasługi</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_about.py" line="65"/>
+        <location filename="ui_about.py"/>
         <source>License</source>
         <translation>Licencja</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_about.py" line="66"/>
+        <location filename="ui_about.py"/>
         <source>Close</source>
         <translation>Zamknij</translation>
     </message>
     <message>
-        <location filename="src/about.py" line="48"/>
-        <source>WatchVideo is a small application to play or download videos from various youtube-like sites.
-It&apos;s made in PyQt4.</source>
-        <translation type="obsolete">WatchVideo jest małym programem pobierającym lub odtwarzającym filmy ze stron takich jak YouTube.
-Korzysta z PyQt4.</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/about.py" line="44"/>
+        <location filename="about.py"/>
         <source>Version: </source>
         <translation>Wersja:</translation>
     </message>
     <message>
-        <location filename="watchvideo/about.py" line="48"/>
-        <source>WatchVideo is a small application to play, download or convert videos (to Ogg) from various youtube-like sites.
-It&apos;s made in PyQt4.</source>
-        <translation type="obsolete">WatchVideo jest małym programem pobierającym, odtwarzającym i konwertującym do Ogg filmy ze stron takich jak YouTube.
-Korzysta z PyQt4.</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/about.py" line="37"/>
+        <location filename="about.py"/>
         <source>
 
 WatchVideo is a small application to play, download or convert videos (to Ogg) from various youtube-like sites.
 It&apos;s made in PyQt4.</source>
-        <translation type="unfinished"></translation>
+        <translation>WatchVideo jest małym programem pobierającym, odtwarzającym i konwertującym do Ogg filmy ze stron takich jak YouTube.
+Korzysta z PyQt4.</translation>
     </message>
 </context>
 <context>
     <name>AddVideos</name>
     <message>
-        <location filename="watchvideo/ui_add_videos.py" line="167"/>
-        <source>Add</source>
-        <translation>Dodaj</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_add_videos.py" line="169"/>
+        <location filename="ui_add_videos.py"/>
         <source>Download</source>
         <translation>Pobierz</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_add_videos.py" line="170"/>
+        <location filename="ui_add_videos.py"/>
         <source>Destination Folder:</source>
         <translation>Katalog docelowy:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_add_videos.py" line="171"/>
+        <location filename="ui_add_videos.py"/>
         <source>Choose Folder</source>
         <translation>Wybierz katalog</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_add_videos.py" line="173"/>
+        <location filename="ui_add_videos.py"/>
         <source>After Download:</source>
         <translation>Po pobraniu:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_add_videos.py" line="174"/>
+        <location filename="ui_add_videos.py"/>
         <source>Do Nothing</source>
         <translation>Nic nie rób</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_add_videos.py" line="175"/>
+        <location filename="ui_add_videos.py"/>
         <source>Play</source>
         <translation>Odtwórz</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_add_videos.py" line="176"/>
+        <location filename="ui_add_videos.py"/>
         <source>Convert to Ogg/Vorbis (audio)</source>
         <translation>Skonwertuj do Ogg Vorbis (dźwięk)</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_add_videos.py" line="177"/>
+        <location filename="ui_add_videos.py"/>
         <source>Convert to Ogg/Theora (video)</source>
         <translation>Skonwertuj do Ogg Theora (film)</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_add_videos.py" line="178"/>
+        <location filename="ui_add_videos.py"/>
         <source>Rip Audio</source>
         <translation>Pobierz dźwięk</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_add_videos.py" line="161"/>
+        <location filename="ui_add_videos.py"/>
         <source>Add Videos</source>
         <translation>Dodaj filmy</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_add_videos.py" line="162"/>
+        <location filename="ui_add_videos.py"/>
         <source>Paste link(s) here:</source>
         <translation>Wklej linki tutaj:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_add_videos.py" line="136"/>
-        <source>Check Links</source>
-        <translation type="obsolete">Sprawdź linki</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_add_videos.py" line="165"/>
+        <location filename="ui_add_videos.py"/>
         <source>Title</source>
         <translation>Tytuł</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_add_videos.py" line="166"/>
-        <source>Url</source>
-        <translation>URL</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_add_videos.py" line="168"/>
+        <location filename="ui_add_videos.py"/>
         <source>Play directly from link(s)</source>
-        <translation>Odtwórz bezpośrednio z linków</translation>
+        <translation>Odtwórz bezpośrednio z linków</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_add_videos.py" line="172"/>
+        <location filename="ui_add_videos.py"/>
         <source>...</source>
         <translation>...</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_add_videos.py" line="164"/>
-        <source>Get in high quality, if possible.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_add_videos.py" line="163"/>
+        <location filename="ui_add_videos.py"/>
         <source>Get Videos</source>
-        <translation type="unfinished"></translation>
+        <translation>Pobierz filmy</translation>
     </message>
 </context>
 <context>
     <name>AddVideosDialog</name>
     <message>
-        <location filename="watchvideo/add_videos.py" line="41"/>
+        <location filename="add_videos.py"/>
         <source>Add</source>
         <translation>Dodaj</translation>
     </message>
     <message>
-        <location filename="watchvideo/add_videos.py" line="175"/>
+        <location filename="add_videos.py"/>
         <source>Warning</source>
         <translation>Ostrzeżenie</translation>
     </message>
     <message>
-        <location filename="watchvideo/add_videos.py" line="175"/>
+        <location filename="add_videos.py"/>
         <source>The given download folder doesn&apos;t exist!</source>
         <translation>Katalog docelowy nie istnieje!</translation>
     </message>
     <message>
-        <location filename="watchvideo/add_videos.py" line="191"/>
+        <location filename="add_videos.py"/>
         <source>Overwrite</source>
         <translation>Nadpisz</translation>
     </message>
     <message>
-        <location filename="watchvideo/add_videos.py" line="191"/>
+        <location filename="add_videos.py"/>
         <source>Do you wish to overwrite this file?</source>
         <translation>Czy nadpisać ten plik?</translation>
     </message>
     <message>
-        <location filename="watchvideo/add_videos.py" line="205"/>
+        <location filename="add_videos.py"/>
         <source>There are no valid links to add!</source>
         <translation>Nie odnaleziono poprawnych linków do dodania!</translation>
     </message>
+    <message>
+        <location filename="add_videos.py"/>
+        <source>Choose Format</source>
+        <translation>Wybierz format</translation>
+    </message>
+</context>
+<context>
+    <name>ChooseFormat</name>
+    <message>
+        <location filename="ui_choose_format.py"/>
+        <source>Choose Format</source>
+        <translation>Wybierz format</translation>
+    </message>
+    <message>
+        <location filename="ui_choose_format.py"/>
+        <source>Title</source>
+        <translation>Tytuł</translation>
+    </message>
+    <message>
+        <location filename="ui_choose_format.py"/>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
 </context>
 <context>
     <name>Gui</name>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="463"/>
+        <location filename="watchvideo_gui.py"/>
         <source>No supported services were found</source>
         <translation>Nie odnaleziono wspieranych usług</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="464"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Close</source>
         <translation>Zamknij</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="466"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Currently checking: </source>
         <translation>Aktualnie sprawdzane:</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="553"/>
-        <source>Opening download directory </source>
-        <translation>Otwieranie katalogu pobierania</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="553"/>
-        <source>with</source>
-        <translation>z</translation>
-    </message>
-    <message>
-        <location filename="src/watchvideo_gui.py" line="326"/>
-        <source>download</source>
-        <translation type="obsolete">pobierz</translation>
-    </message>
-    <message>
-        <location filename="src/watchvideo_gui.py" line="330"/>
-        <source>play</source>
-        <translation type="obsolete">odtwórz</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="130"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Start</source>
         <translation>Rozpocznij</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="131"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Stop</source>
         <translation>Zakończ</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="132"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Remove</source>
         <translation>Usuń</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="133"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Remove and delete file</source>
-        <translation>Usuń wraz z plikiem</translation>
+        <translation>Usuń wraz z plikiem</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="134"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Open Folder</source>
         <translation>Otwórz katalog</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="135"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Copy original URL</source>
         <translation>Skopiuj oryginalny URL</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="516"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Download Finished</source>
         <translation>Pobieranie zakończone</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="644"/>
-        <source>There are still downloads active, do you really want to quit?
-(you won&apos;t be able to continue the downloads after quit)</source>
-        <translation type="obsolete">Pliki są nadal pobierane, czy chcesz je przerwać?
-(nie zostaną wznowione po ponownym uruchomieniu programu)</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="456"/>
-        <source>Play</source>
-        <translation>Odtwórz</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="365"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Ripping audio of</source>
         <translation>Pobieranie dźwięku z</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="366"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Audio Ripped</source>
         <translation>Dźwięk pobrany</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="369"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Converting video:</source>
         <translation>Konwertowanie filmu:</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="370"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Video Converted</source>
         <translation>Film skonwertowany</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="451"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Download</source>
         <translation>Pobierz</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="367"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Error ripping audio</source>
         <translation>Błąd pobierania dźwięku</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="371"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Error converting video</source>
         <translation>Błąd konwersji filmu</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="136"/>
+        <location filename="watchvideo_gui.py"/>
         <source>Play local file</source>
         <translation>Odtwórz plik lokalny</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="649"/>
+        <location filename="watchvideo_gui.py"/>
         <source>There are still some tasks active, do you really want to quit?
 (you won&apos;t be able to continue them after quitting)</source>
+        <translation>Pewne zadania są nadal wykonywane, czy na pewno chcesz zakończyć?
+(nie zostaną wznowione po ponownym uruchomieniu programu)</translation>
+    </message>
+    <message>
+        <location filename="watchvideo_gui.py"/>
+        <source>No valid URLs found.</source>
+        <translation>Nie znaleziono znanych linków.</translation>
+    </message>
+    <message>
+        <location filename="watchvideo_gui.py"/>
+        <source>Opening download directory %s with %s</source>
+        <translation>Otwieranie katalogu pobierania %s przez %s</translation>
+    </message>
+    <message>
+        <location filename="watchvideo_gui.py"/>
+        <source>This will abort the download(s) too, are you sure?</source>
+        <translation>Pobieranie zostanie również przerwane, czy zakończyć?</translation>
+    </message>
+    <message>
+        <location filename="watchvideo_gui.py"/>
+        <source>A dialog to choose the format will appear for all videos with more than one format available.</source>
+        <translation>Dla filmów dostępnych w wielu formatach pojawi się okno wyboru formatu.</translation>
+    </message>
+    <message>
+        <location filename="watchvideo_gui.py"/>
+        <source>All videos are played/downloaded in the lowest quality available.</source>
+        <translation>Wszystkie filmy są odtwarzane/pobierane w najniższej dostępnej jakości.</translation>
+    </message>
+    <message>
+        <location filename="watchvideo_gui.py"/>
+        <source>All videos are played/downloaded in the highest quality available.</source>
+        <translation>Wszystkie filmy są odtwarzane/pobierane w najwyższej dostępnej jakości.</translation>
+    </message>
+    <message>
+        <source>The videos will be played/downloaded according to what
+            was defined in preferences. By default it prompts to choose the format.</source>
+        <translation type="obsolete">Filmy zostaną odtworzone/pobrane w formacie wybranym w preferencjach. Domyślnie program zapyta o format.</translation>
+    </message>
+    <message>
+        <location filename="watchvideo_gui.py"/>
+        <source>Don&apos;t repeat</source>
+        <translation>Nie powtarzaj</translation>
+    </message>
+    <message>
+        <location filename="watchvideo_gui.py"/>
+        <source>Repeat track</source>
+        <translation>Powtórz utwór</translation>
+    </message>
+    <message>
+        <location filename="watchvideo_gui.py"/>
+        <source>Repeat playlist</source>
+        <translation>Powtórz listę</translation>
+    </message>
+    <message>
+        <location filename="watchvideo_gui.py"/>
+        <source>The videos are played/downloaded according to what was defined in preferences. If it&apos;s the first time accessing a particular website through WatchVideo, the default action will be to ask for the quality.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="watchvideo/ui_main.py" line="168"/>
-        <source>WatchVideo</source>
-        <translation>WatchVideo</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_main.py" line="169"/>
+        <location filename="ui_main.py"/>
         <source>Title</source>
         <translation>Tytuł</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="170"/>
+        <location filename="ui_main.py"/>
         <source>Size</source>
         <translation>Rozmiar</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="171"/>
+        <location filename="ui_main.py"/>
         <source>Progress</source>
         <translation>Postęp</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="172"/>
+        <location filename="ui_main.py"/>
         <source>Speed</source>
         <translation>Prędkość</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="173"/>
+        <location filename="ui_main.py"/>
         <source>Time Left</source>
         <translation>Pozostały czas</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="174"/>
+        <location filename="ui_main.py"/>
         <source>File</source>
         <translation>Plik</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="175"/>
+        <location filename="ui_main.py"/>
         <source>Edit</source>
         <translation>Edycja</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="176"/>
+        <location filename="ui_main.py"/>
         <source>Help</source>
         <translation>Pomoc</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="177"/>
-        <source>toolBar</source>
-        <translation>Pasek narzędzi</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_main.py" line="178"/>
+        <location filename="ui_main.py"/>
         <source>Shortcut to get the links from the clipboard</source>
-        <translation>Skrót do wstawienia linków z schowka</translation>
+        <translation>Skrót do wstawienia linków z schowka</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="179"/>
+        <location filename="ui_main.py"/>
         <source>Add Videos</source>
         <translation>Dodaj filmy</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="180"/>
+        <location filename="ui_main.py"/>
         <source>Add one or more links to download or play directly in your favorite mediaplayer.</source>
-        <translation>Dodaj jeden lub więcej linków do pobrania lub otworzenia w Twoim ulubionym odtwarzaczu.</translation>
+        <translation>Dodaj jeden lub więcej linków do pobrania lub otworzenia w Twoim ulubionym odtwarzaczu.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="181"/>
+        <location filename="ui_main.py"/>
         <source>Search Browser</source>
-        <translation>Znajdź z przeglądarki</translation>
+        <translation>Znajdź z przeglądarki</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="182"/>
+        <location filename="ui_main.py"/>
         <source>Searches open windows and tabs in your browser for flash videos (only Firefox and derivatives are suported)</source>
-        <translation>Szuka filmów używających Flash w otwartych oknach i kartach przeglądarki opartej na Firefoksie</translation>
+        <translation>Szuka filmów używających Flash w otwartych oknach i kartach przeglądarki opartej na Firefoksie</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="183"/>
+        <location filename="ui_main.py"/>
         <source>Clear Completed</source>
         <translation>Czyszczenie zakończone</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="184"/>
+        <location filename="ui_main.py"/>
         <source>About</source>
-        <translation>O programie</translation>
+        <translation>O programie</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="185"/>
+        <location filename="ui_main.py"/>
         <source>Preferences</source>
         <translation>Ustawienia</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="186"/>
+        <location filename="ui_main.py"/>
         <source>Quit</source>
         <translation>Wyjdź</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="187"/>
+        <location filename="ui_main.py"/>
         <source>Clipboard</source>
         <translation>Schowek</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="188"/>
+        <location filename="ui_main.py"/>
         <source>Fetch link from the clipboard</source>
         <translation>Pobierz linki z schowka</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="189"/>
+        <location filename="ui_main.py"/>
         <source>Play</source>
         <translation>Odtwórz</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="190"/>
+        <location filename="ui_main.py"/>
         <source>Shortcut to play the video(s) from the url(s) on the clipboard</source>
         <translation>Skrót do otworzenia filmów z URL-i w schowku</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="191"/>
+        <location filename="ui_main.py"/>
         <source>Download</source>
         <translation>Pobierz</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="192"/>
+        <location filename="ui_main.py"/>
         <source>Shortcut to download the video(s) from the url(s) on the clipboard</source>
         <translation>Skrót do pobrania filmów z URL-i w schowku</translation>
     </message>
+    <message>
+        <location filename="ui_main.py"/>
+        <source>Player</source>
+        <translation>Odtwarzacz</translation>
+    </message>
+    <message>
+        <location filename="ui_main.py"/>
+        <source>Downloads</source>
+        <translation>Pobieranie</translation>
+    </message>
+    <message>
+        <location filename="ui_main.py"/>
+        <source>View</source>
+        <translation>Widok</translation>
+    </message>
+    <message>
+        <location filename="ui_main.py"/>
+        <source>Search</source>
+        <translation>Wyszukiwanie</translation>
+    </message>
+    <message>
+        <source>Ask</source>
+        <translation type="obsolete">Pytaj</translation>
+    </message>
+    <message>
+        <source>Low</source>
+        <translation type="obsolete">Niska</translation>
+    </message>
+    <message>
+        <source>High</source>
+        <translation type="obsolete">Wysoka</translation>
+    </message>
+</context>
+<context>
+    <name>Player</name>
+    <message>
+        <source>This will abort the download too, are you sure?</source>
+        <translation type="obsolete">Pobieranie zostanie również przerwane, czy zakończyć?</translation>
+    </message>
+    <message>
+        <location filename="player.py"/>
+        <source>Loading video, please wait...</source>
+        <translation>Wczytywanie filmu, proszę czekać...</translation>
+    </message>
+    <message>
+        <source>Ask</source>
+        <translation type="obsolete">Pytaj</translation>
+    </message>
+    <message>
+        <source>Low</source>
+        <translation type="obsolete">Niska</translation>
+    </message>
+    <message>
+        <source>High</source>
+        <translation type="obsolete">Wysoka</translation>
+    </message>
 </context>
 <context>
     <name>Preferences</name>
     <message>
-        <location filename="watchvideo/preferences.py" line="183"/>
+        <location filename="preferences.py"/>
         <source>Media Player</source>
         <translation>Odtwarzacz</translation>
     </message>
     <message>
-        <location filename="watchvideo/preferences.py" line="183"/>
+        <location filename="preferences.py"/>
         <source>Given media player is not valid</source>
         <translation>Wybrano nieprawidłowy odtwarzacz</translation>
     </message>
+    <message>
+        <source>Ask</source>
+        <translation type="obsolete">Pytaj</translation>
+    </message>
+    <message>
+        <source>Low</source>
+        <translation type="obsolete">Niska</translation>
+    </message>
+    <message>
+        <source>High</source>
+        <translation type="obsolete">Wysoka</translation>
+    </message>
+    <message>
+        <location filename="preferences.py"/>
+        <source>Ask Quality</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="preferences.py"/>
+        <source>Low Quality</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="preferences.py"/>
+        <source>High Quality</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PreferencesWindow</name>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="182"/>
+        <location filename="ui_preferences.py"/>
         <source>Preferences</source>
         <translation>Ustawienia</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="184"/>
+        <location filename="ui_preferences.py"/>
         <source>Default media player:</source>
         <translation>Domyślny odtwarzacz:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="188"/>
-        <source>...</source>
-        <translation>...</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_preferences.py" line="182"/>
-        <source>Save played or downloaded urls in history</source>
-        <translation type="obsolete">Zapamiętaj odtwarzane lub pobrane URL w historii</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_preferences.py" line="183"/>
-        <source>Save permanently (urls will be saved to disk)</source>
-        <translation type="obsolete">Zapisz URL-e na dysk</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_preferences.py" line="186"/>
+        <location filename="ui_preferences.py"/>
         <source>General</source>
         <translation>Ogólne</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="187"/>
+        <location filename="ui_preferences.py"/>
         <source>Default download folder:</source>
         <translation>Domyślny katalog pobierania:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="189"/>
+        <location filename="ui_preferences.py"/>
         <source>Default action after download:</source>
         <translation>Domyśle działanie po pobraniu:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="190"/>
+        <location filename="ui_preferences.py"/>
         <source>Do Nothing</source>
         <translation>Nic nie rób</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="191"/>
+        <location filename="ui_preferences.py"/>
         <source>Play</source>
         <translation>Odtwórz</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="192"/>
+        <location filename="ui_preferences.py"/>
         <source>Convert to Ogg/Vorbis (Audio)</source>
         <translation>Skonwertuj do Ogg Vorbis (dźwięk)</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="193"/>
+        <location filename="ui_preferences.py"/>
         <source>Convert to Ogg/Theora (Video)</source>
         <translation>Skonwertuj do Ogg Theora (film)</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="194"/>
+        <location filename="ui_preferences.py"/>
         <source>Rip Audio</source>
         <translation>Pobierz dźwięk</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="198"/>
+        <location filename="ui_preferences.py"/>
         <source>Download Options</source>
         <translation>Opcje pobierania</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="189"/>
-        <source>Youtube</source>
-        <translation type="obsolete">YouTube</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_preferences.py" line="209"/>
-        <source>High Quality</source>
-        <translation type="obsolete">Wysoka jakość</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_preferences.py" line="210"/>
-        <source>Low Quality</source>
-        <translation type="obsolete">Niska jakość</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_preferences.py" line="208"/>
-        <source>Blip.tv</source>
-        <translation type="obsolete">Blip.tv</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_preferences.py" line="204"/>
+        <location filename="ui_preferences.py"/>
         <source>Video Quality</source>
         <translation>Jakość filmu</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="205"/>
+        <location filename="ui_preferences.py"/>
         <source>Notification Messages</source>
         <translation>Powiadomienia</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="206"/>
+        <location filename="ui_preferences.py"/>
         <source>The download ends successfully.</source>
-        <translation>Pobieranie zakończone z powodzeniem.</translation>
+        <translation>Pobieranie zakończone z powodzeniem.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="207"/>
+        <location filename="ui_preferences.py"/>
         <source>Show a notification message when:</source>
         <translation>Wyświetl powiadomienie gdy:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="194"/>
-        <source>The download fails.</source>
-        <translation type="obsolete">Pobieranie nie powiodło się.</translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_preferences.py" line="212"/>
+        <location filename="ui_preferences.py"/>
         <source>Notifications</source>
         <translation>Powiadomienia</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="209"/>
+        <location filename="ui_preferences.py"/>
         <source>If you want to use your system&apos;s default way to popup messages you can install &apos;python-notify&apos;. 
 In case python-notify isn&apos;t installed, WatchVideo uses baloon tooltips on the tray icon provided by Qt4.</source>
         <translation>Jeżeli chcesz użyć systemowe powiadomienia, zainstaluj pakiet „python-notify”.
-Jeżeli nie jest on zainstalowany, to WatchVideo użyje powiadomienia z Qt4.</translation>
+Jeżeli nie jest on zainstalowany, to WatchVideo użyje powiadomienia z Qt4.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="211"/>
+        <location filename="ui_preferences.py"/>
         <source>Note:</source>
         <translation>Uwaga:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="195"/>
+        <location filename="ui_preferences.py"/>
         <source>When double-clicking a completed download:</source>
-        <translation>Przy podwójnym kilknięciu pobranego pliku:</translation>
+        <translation>Przy podwójnym kliknięciu pobranego pliku:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="196"/>
+        <location filename="ui_preferences.py"/>
         <source>Play Local File</source>
         <translation>Odtwórz plik lokalny</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="197"/>
+        <location filename="ui_preferences.py"/>
         <source>Open Folder</source>
         <translation>Otwórz katalog</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="199"/>
+        <location filename="ui_preferences.py"/>
         <source>Website</source>
-        <translation type="unfinished"></translation>
+        <translation>Strona</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="201"/>
-        <source>All High Quality</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_preferences.py" line="202"/>
-        <source>All low quality</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="watchvideo/ui_preferences.py" line="203"/>
+        <location filename="ui_preferences.py"/>
         <source>Mixed</source>
-        <translation type="unfinished"></translation>
+        <translation>Różne</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="208"/>
+        <location filename="ui_preferences.py"/>
         <source>An error occurs.</source>
-        <translation type="unfinished"></translation>
+        <translation>Wystąpił błąd.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="183"/>
+        <location filename="ui_preferences.py"/>
         <source>Use built-in player.</source>
+        <translation>Użyj wbudowany odtwarzacz.</translation>
+    </message>
+    <message>
+        <location filename="ui_preferences.py"/>
+        <source>All Ask</source>
+        <translation>Zawsze pytaj</translation>
+    </message>
+    <message>
+        <location filename="ui_preferences.py"/>
+        <source>All Low</source>
+        <translation>Zawsze niska</translation>
+    </message>
+    <message>
+        <location filename="ui_preferences.py"/>
+        <source>All High</source>
+        <translation>Zawsze wysoka</translation>
+    </message>
+    <message>
+        <location filename="ui_preferences.py"/>
+        <source>Apply to all websites (ignore list below).</source>
+        <translation>Zastosuj dla wszystkich stron (ignoruje poniższą listę).</translation>
+    </message>
+    <message>
+        <location filename="ui_preferences.py"/>
+        <source>This list contains the websites that you already accessed through WatchVideo.</source>
+        <translation>Ta lista zawiera strony jakie zostały już odwiedzone przez WatchVideo.</translation>
+    </message>
+    <message>
+        <location filename="ui_preferences.py"/>
+        <source>Automatically check for links in clipboard.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>Search</name>
+    <message>
+        <location filename="threads.py"/>
+        <source>Show More</source>
+        <translation>Pokaż więcej</translation>
+    </message>
+</context>
+<context>
+    <name>SearchField</name>
+    <message>
+        <location filename="searchfield.py"/>
+        <source>Search...</source>
+        <translation>Szukaj...</translation>
+    </message>
+</context>
 </TS>
