@@ -85,6 +85,9 @@ class AddVideosDialog(QtGui.QDialog):
                 
                 if self.parent.action == "play":
                     self.ui.rb_playDirectly.setChecked(True)
+                else:
+                    self.ui.rb_download.setChecked(True)
+                    
                 
                 self.setWindowTitle(self.tr("Choose Format"))
             else:
@@ -128,6 +131,7 @@ class AddVideosDialog(QtGui.QDialog):
         for i in xrange(self.ui.tree_validLinks.topLevelItemCount()-1, -1, -1):
            self.ui.tree_validLinks.takeTopLevelItem(i)
         self.visible = False
+        print "Closing Add Videos Dialog"
         
         
     def stopChecking(self):
@@ -250,5 +254,7 @@ class AddVideosDialog(QtGui.QDialog):
         self.visible = True
         super(AddVideosDialog, self).show()
 
-    def isFinished():
-        return bool(self.match_url) and self.match_url.done
+    def isFinished(self):
+        if self.match_url:
+            return self.match_url.done
+        return True
