@@ -196,7 +196,9 @@ def play(url, title, player=None):
     '''Play'''
     if player is None:
         player = get_default_player()
+    
     print "Playing %s" % title
+    option = ""
     try:
         if os.name == "nt": 
             os.filestart(url)
@@ -213,7 +215,9 @@ def play(url, title, player=None):
                 print "Player not found!"
                 raise KeyboardInterrupt
             
-            Popen((player, url))
+            if player == "totem": option = "--enqueue"
+            
+            Popen((player, option, url))
     except KeyboardInterrupt:
         print '\r'
         sys.exit()
