@@ -20,6 +20,7 @@ from threading import Thread
 import sys
 import os
 import subprocess
+import time
 try:
     import json
     assert json
@@ -249,14 +250,12 @@ class Gui(QtGui.QMainWindow):
         
         if "http" in self.clipboard.text():
             text = self.clipboard.text().split()
-            text = [ url for url in text if url not in self.visited_urls ]
-            self.visited_urls += text
+            text = [ url for url in text if url not in self.visited_urls and "http://" in url ]
             
             if text:
                 self.action = "clipboard-auto"
                 self.getFilesUrl(text)
             
-        #print self.clipboard.text()
       
     def showPlayerRightClickMenu(self):
         if self.player and self.player.download:
@@ -547,9 +546,12 @@ class Gui(QtGui.QMainWindow):
                     item = DownloadItem(video.url, video.dl_url, video.filepath, video.after_complete, self)
                     self.player.loadfile(video.filepath, item)
             else:
+                #names = [video.name for video in videos]
+                #urls = [video.dl_url for video in videos]
                 for video in videos:
                     Thread(target=main.play, args=(video.dl_url, video.name,
-                    self.settings.media_player)).start()
+                        self.settings.media_player)).start()
+                    time.sleep(2)
                 
         
         
@@ -628,9 +630,11 @@ class Gui(QtGui.QMainWindow):
             self.ui.statusbar.insertPermanentWidget(0, self.b_cancelSearch)
             self.cleanStatusTip()
             
-            quality = self.global_quality
+            
             if "clipboard" in self.action: 
                 quality = "ask"
+            else:
+                quality = self.global_quality
             
             self.match_url = main.Match(urls, quality, fast=False) #start a check thread       
             Thread(target=self.match_url.match, args=()).start()
@@ -661,7 +665,7 @@ class Gui(QtGui.QMainWindow):
             
             #append mediums' urls to the visited urls
             for medium in mediums.keys() + ready_mediums.keys():
-                self.visited_urls.append(medium.title)
+                self.visited_urls.append(medium.url)
             
             if self.action == "clipboard-auto":
                 for medium in mediums: 
@@ -991,7 +995,8 @@ class Gui(QtGui.QMainWindow):
         self.close()
     
     def closeEvent(self, event):
-        if self.active_download_items or (self.player and self.player.isActive()):
+        if self.active_download_items or (self.player and self.player.isActive()) or (
+        self.dialogs["add_videos"] and not self.dialogs["add_videos"].isFinished()):
             if self.show_confirm_dialog:
                 answer = gui_utils.confirm(self, title="Quit?",
                 msg=self.tr("There are still some tasks active, do you really want to quit?" + 
@@ -1010,6 +1015,7 @@ class Gui(QtGui.QMainWindow):
             else:
                 event.ignore()
                 return
+           
 
         self.saveWindow()
         
